@@ -2,9 +2,8 @@
 A collection of bands extraction EOTasks
 
 Credits:
-Copyright (c) 2017-2019 Matej Aleksandrov, Matej Batič, Andrej Burja, Eva Erzin (Sinergise)
-Copyright (c) 2017-2019 Grega Milčinski, Matic Lubej, Devis Peresutti, Jernej Puc, Tomislav Slijepčević (Sinergise)
-Copyright (c) 2017-2019 Blaž Sovdat, Nejc Vesel, Jovan Višnjić, Anže Zupanc, Lojze Žust (Sinergise)
+Copyright (c) 2017-2022 Matej Aleksandrov, Matej Batič, Grega Milčinski, Domagoj Korais, Matic Lubej (Sinergise)
+Copyright (c) 2017-2022 Žiga Lukšič, Devis Peressutti, Nejc Vesel, Jovan Višnjić, Anže Zupanc (Sinergise)
 
 This source code is licensed under the MIT license found in the LICENSE
 file in the root directory of this source tree.
@@ -16,7 +15,7 @@ from eolearn.core import MapFeatureTask
 
 
 class EuclideanNormTask(MapFeatureTask):
-    """ The task calculates the Euclidean Norm:
+    """The task calculates the Euclidean Norm:
 
         :math:`Norm = \\sqrt{\\sum_{i} B_i^2}`
 
@@ -45,13 +44,13 @@ class EuclideanNormTask(MapFeatureTask):
 
 
 class NormalizedDifferenceIndexTask(MapFeatureTask):
-    """ The task calculates a Normalized Difference Index (NDI) between two bands A and B as:
+    """The task calculates a Normalized Difference Index (NDI) between two bands A and B as:
 
-        :math:`NDI = \\dfrac{A-B+c}{A+B+c}`,
+    :math:`NDI = \\dfrac{A-B+c}{A+B+c}`,
 
-        where c is provided as the *acorvi_constant* argument. For the reasoning behind using the acorvi_constant in the
-        equation, check the article `Using NDVI with atmospherically corrected data
-        <http://www.cesbio.ups-tlse.fr/multitemp/?p=12746>`_.
+    where c is provided as the *acorvi_constant* argument. For the reasoning behind using the acorvi_constant in the
+    equation, check the article `Using NDVI with atmospherically corrected data
+    <http://www.cesbio.ups-tlse.fr/multitemp/?p=12746>`_.
     """
 
     def __init__(self, input_feature, output_feature, bands, acorvi_constant=0, undefined_value=np.nan):
@@ -69,7 +68,7 @@ class NormalizedDifferenceIndexTask(MapFeatureTask):
         super().__init__(input_feature, output_feature)
 
         if not isinstance(bands, (list, tuple)) or len(bands) != 2 or not all(isinstance(x, int) for x in bands):
-            raise ValueError('bands argument should be a list or tuple of two integers!')
+            raise ValueError("bands argument should be a list or tuple of two integers!")
 
         self.band_a, self.band_b = bands
         self.undefined_value = undefined_value
@@ -82,7 +81,7 @@ class NormalizedDifferenceIndexTask(MapFeatureTask):
         """
         band_a, band_b = feature[..., self.band_a], feature[..., self.band_b]
 
-        with np.errstate(divide='ignore', invalid='ignore'):
+        with np.errstate(divide="ignore", invalid="ignore"):
             ndi = (band_a - band_b + self.acorvi_constant) / (band_a + band_b + self.acorvi_constant)
 
         ndi[~np.isfinite(ndi)] = self.undefined_value
